@@ -286,15 +286,17 @@ int pth_poll_ev(struct pollfd *pfd, unsigned int nfd, int timeout, pth_event_t e
         ptv->tv_sec  = 0;
         ptv->tv_usec = 0;
     }
-    else if (timeout == INFTIM) {
+    else if (timeout == INFTIM /* (-1) */) {
         /* wait forever */
         ptv = NULL;
     }
-    else {
+    else if (timeout > 0) {
         /* return after timeout */
         ptv->tv_sec  = timeout / 1000;
         ptv->tv_usec = (timeout % 1000) * 1000;
     }
+    else 
+        return_errno(-1, EINVAL);
 
     /* create fd sets and determine max fd */
     maxfd = -1;
