@@ -21,7 +21,10 @@
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 **  USA, or contact Ralf S. Engelschall <rse@engelschall.com>.
 */
-
+                             /* ``Unix was not designed to stop people 
+                                  from doing stupid things, because that 
+                                  would also stop them from doing clever 
+                                  things.''         --Doug Gwyn          */
 #include "pth_p.h"
 
 intern void pth_ring_init(pth_ring_t *r, pth_ringnode_t *rn)
