@@ -21,7 +21,11 @@
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 **  USA, or contact Ralf S. Engelschall <rse@engelschall.com>.
 */
-
+                             /* ``Free Software: generous programmers 
+                                  from around the world all join 
+                                  forces to help you shoot yourself 
+                                  in the foot for free.''
+                                                 -- Unknown         */
 #include "pth_p.h"
 
 #if cpp
