@@ -21,7 +21,9 @@
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 **  USA, or contact Ralf S. Engelschall <rse@engelschall.com>.
 */
-
+                             /* ``It doesn't need to be tested, 
+                                  because it works.''
+                                           -- Richard Holloway */
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -83,13 +85,14 @@ ssize_t pth_readline(int fd, void *buf, size_t buflen)
 
 ssize_t pth_readline_ev(int fd, void *buf, size_t buflen, pth_event_t ev_extra)
 {
-    int n, rc;
+    size_t n;
+    ssize_t rc;
     char c, *cp;
     readline_buf *rl;
 
     pth_once(&readline_once_ctrl, readline_init, NULL);
     if ((rl = (readline_buf *)pth_key_getdata(readline_key)) == NULL) {
-        rl = malloc(sizeof(readline_buf));
+        rl = (readline_buf *)malloc(sizeof(readline_buf));
         rl->rl_cnt = 0;
         rl->rl_bufptr = NULL;
         pth_key_setdata(readline_key, rl);
