@@ -52,14 +52,11 @@ static void *handler(void *_arg)
     char str[1024];
     int n;
 
-    /* switch socket to non-blocking I/O mode */
-    pth_nonblocking(fd);
-
     /* read request */
     for (;;) {
         n = pth_readline(fd, caLine, MAXREQLINE);
         if (n < 0) {
-            fprintf(stderr, "read error");
+            fprintf(stderr, "read error: errno=%d\n", errno);
             close(fd);
             return NULL;
         }
@@ -80,7 +77,7 @@ static void *handler(void *_arg)
                  "Content-type: text/plain\r\n"
                  "\r\n"
                  "Just a trivial test for GNU Pth\n"
-                 "to show that's serving data.\r\n", PTH_VERSION); 
+                 "to show that it's serving data.\r\n", PTH_VERSION); 
     pth_write(fd, str, strlen(str));
 
     /* close connection and let thread die */
@@ -188,9 +185,6 @@ int main(int argc, char *argv[])
         exit(1);
     }
 
-    /* switch socket to non-blocking I/O mode */
-    pth_nonblocking(s);
-
     /* bind socket to port */
     sar.sin_family      = AF_INET;
     sar.sin_addr.s_addr = INADDR_ANY;
